Version history
===============

v2.0.0

- Add support modern version of Django
- Moved "send mail" code from 'form' to 'view' module
- Add raise ImproperlyConfigured exception, if ADMINS or MANAGERS is not set

v1.0.0

- First release

